##!/bin/sh

set -eux
# setup env
while getopts "c:p:t:" opt; do
  case $opt in
    c)
      cert_data=$OPTARG
      ;;
    p)
      password=$OPTARG
      ;;
    t)
      temp_path=$OPTARG
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
  esac
done

echo "--------------------------------------------------------------------------------"
echo "Start to import certificate"
echo "--------------------------------------------------------------------------------"

# create variables
CERTIFICATE_PATH=$temp_path/build_certificate.p12
PP_PATH=$temp_path/build_pp.mobileprovision
KEYCHAIN_PATH=$temp_path/app-signing.keychain-db


# import certificate and provisioning profile from secrets
echo -n "$cert_data" | base64 --decode --output $CERTIFICATE_PATH


# create temporary keychain
security create-keychain -p "" $KEYCHAIN_PATH
security list-keychains -d user -s $KEYCHAIN_PATH
security default-keychain -s $KEYCHAIN_PATH
security unlock-keychain -p "" $KEYCHAIN_PATH
security set-keychain-settings -lut 21600 $KEYCHAIN_PATH

# import certificate to keychain
security import $CERTIFICATE_PATH \
                -t cert \
                -f pkcs12 \
                -P $password \
                -k $KEYCHAIN_PATH \
                -A
                
security set-key-partition-list -S apple-tool:,apple: -s -k "" $KEYCHAIN_PATH