##!/bin/sh

set -eux
# setup env
while getopts "s:d:c:" opt; do
  case $opt in
    s)
      project_path=$OPTARG
      ;;
    d)
      scripts_Path=$OPTARG
      ;;
    c)
      configuration=$OPTARG
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
  esac
done

build_Path=$scripts_Path/build

if [ ! -d $build_Path ]
then
  mkdir $build_Path
fi

# 工程名
project_name=Runner

# Scheme名 
project_scheme=Runner

# 编译模式
build_type=$configuration

# workspace名
project_workspace=$project_path/${project_name}.xcworkspace

# archive_path        eg:$project_path/$project_name.xcarchive
archive_path=$build_Path/${project_name}.xcarchive

# ipa文件存放路径        eg:$project_path
export_ipa_path=$build_Path

# exportOptions plist       eg:$project_path/ExportOptions.plist
export_options_plist=$scripts_Path/delivery/ExportOptions.plist

echo "--------------------------------------------------------------------------------"
echo "Start to packaging iOS configuration: $configuration"
echo "--------------------------------------------------------------------------------"

echo "Clean workspace"
xcodebuild clean -workspace $project_workspace -scheme $project_scheme -configuration $build_type -quiet || exit

echo "Archive project"
xcodebuild archive -workspace ${project_workspace} -scheme ${project_scheme} -configuration $build_type -archivePath $archive_path -quiet || exit

echo "Export ipa! The ipa path is ${export_ipa_path}"
xcodebuild -exportArchive -archivePath $archive_path -exportPath ${export_ipa_path} -exportOptionsPlist ${export_options_plist} -quiet || exit
