#!/bin/bash

set -eu

iOSSDKBuildNumber="1"

while getopts "i:p:b:" opt; do
  case $opt in
    i)
      iOSSDKProjectPath=$(cd $OPTARG; pwd)
      ;;
    p)
      projectPath=$(cd $OPTARG; pwd)
      ;;
    b)
      iOSSDKBuildNumber=$OPTARG
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
  esac
done

echo "iOSSDKProjectPath: $iOSSDKProjectPath"
echo "projectPath: $projectPath"
echo "iOSSDKBuildNumber: $iOSSDKBuildNumber"

dependencyVersion=$(cat "$projectPath/ios/fw_flutter_sdk.podspec" | grep 's.dependency "FireworkVideo"' | awk -F ", " '{print $2}' | sed 's/"//g')
echo "dependencyVersion: $dependencyVersion"

localSDKPath="$projectPath/tmp/local_ios_sdk"
rm -rf $localSDKPath
mkdir -p $localSDKPath

cd $iOSSDKProjectPath
pwd
ls -l

echo "start build iOS SDK framework"
scripts/create_xcframework.sh -o $localSDKPath -v $dependencyVersion -b $iOSSDKBuildNumber 1> /dev/null

scripts/generate-podspec.sh -v $dependencyVersion -o $localSDKPath -t scripts/FireworkVideo.podspec.Template

cd $projectPath
pwd
ls -l
ls -l $localSDKPath

cd example/ios
podLocalIOSSDK="pod 'FireworkVideo', :path =>"
lineIndexOfPodLocalIOSSDK=$(cat Podfile | grep -n "${podLocalIOSSDK}" | awk -F ":" '{print $1}')
echo "lineIndexOfPodLocalIOSSDK: $lineIndexOfPodLocalIOSSDK"

if [[ -n "$lineIndexOfPodLocalIOSSDK" ]]
then
sed -i "" "${lineIndexOfPodLocalIOSSDK}d" Podfile
fi

flutterInstallAllIOSPods="flutter_install_all_ios_pods"
lineIndexOfFlutterInstallAllIOSPods=$(cat Podfile | grep -n "${flutterInstallAllIOSPods}" | awk -F ":" '{print $1}')
echo "lineIndexOfFlutterInstallAllIOSPods: $lineIndexOfFlutterInstallAllIOSPods"
podLocalFireworkVideo="  pod 'FireworkVideo', :path => '${localSDKPath}'"
echo "podLocalFireworkVideo: $podLocalFireworkVideo"
sed -i "" "$lineIndexOfFlutterInstallAllIOSPods a\ 
${podLocalFireworkVideo}
" Podfile

cd $projectPath
