#!/bin/bash

# setup env
while getopts "s:d:" opt; do
  case $opt in
    s)
      sourceProjPath=$OPTARG
      ;;
    d)
      destinationProjPath=$OPTARG
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
  esac
done

echo "==========begin make FlutterSample proj=========="

cd ${destinationProjPath}

# make dir FireworkRNSDKSample
if [ ! -d FireworkFlutterSDKSample ]
then
	mkdir FireworkFlutterSDKSample
else
  rm -r FireworkFlutterSDKSample
  mkdir FireworkFlutterSDKSample
fi

#copy example
cp -r ${sourceProjPath}/example/. FireworkFlutterSDKSample

#move doc to docs
if [ -d ${sourceProjPath}/doc ]
then
  if [ -d docs ]
  then
    rm -r docs
  fi
  mkdir docs

	cp -r ${sourceProjPath}/doc/. docs
fi

#copy README.md
if [ -f ${sourceProjPath}/README_PUBLIC_REPO.md ]
then
	cp ${sourceProjPath}/README_PUBLIC_REPO.md ./README.md
fi

#copy CHANGELOG.md
if [ -f ${sourceProjPath}/CHANGELOG.md ]
then
	cp ${sourceProjPath}/CHANGELOG.md ./
fi

#copy LICENSE
if [ -f ${sourceProjPath}/LICENSE ]
then
	cp ${sourceProjPath}/LICENSE ./
fi



# make Dart proj
sh ${sourceProjPath}/scripts/synthesis_Dart.sh -s $sourceProjPath -d $destinationProjPath

# make iOS proj
sh ${sourceProjPath}/scripts/synthesis_iOS.sh -o ${destinationProjPath}/FireworkFlutterSDKSample/ios

# make Android proj
sh ${sourceProjPath}/scripts/synthesis_Android.sh -o ${destinationProjPath}/FireworkFlutterSDKSample/android

echo "==========end make FlutterSample proj=========="