#!/bin/bash

SWIFTLINT_VERSION="0.46.2"


STARTING_DIR="$(pwd)"

install_swiftlint() {
    echo "Installing Swiftliint v$SWIFTLINT_VERSION"
    tmp_dir=$(mktemp -d -t swiftlint)
    cd $tmp_dir
    echo "Cloning Swiftlint"
    git clone --depth 1 --branch $SWIFTLINT_VERSION https://github.com/realm/SwiftLint.git
    cd swiftlint
    echo "Running Make Install"
    make install
    if [ $? -ne 0 ]; then
        echo "Failed to install Swiftlint."
        exit 1
    else
        echo "Swiftlint installed"
    fi    
}

uninstall_swiftlint() {
    echo "Uninstalling Swiftlint"
    INSTALLED_DIR="$(which swiftlint)"
    if [[ -z $INSTALLED_DIR ]]; then
        rm -r $INSTALLED_DIR
    fi
    echo "Unistalled Swiftlint"
}

check_swiftlint() {
    echo "Checking Swiftlint"
    if which swiftlint >/dev/null; then
        echo "Detected Swiftlint"
        echo "Checking version"
        if [ "$(swiftlint version)" == "$SWIFTLINT_VERSION" ]; then
            echo "Correct version of Swiftlint installed"
        else
            echo "Inocorrect version of Swiftlint installed"
            uninstall_swiftlint
            install_swiftlint
        fi
    else
        install_swiftlint
    fi
}

check_swiftlint

cd $STARTING_DIR