#!/bin/bash

set -e
while getopts "o:" opt; do
  case $opt in
    o)
      destPath=$OPTARG
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
  esac
done

echo "==========begin make iOS proj=========="

iOSProjPath=${destPath}

echo "ios proj path is ${iOSProjPath}"



# Part 1: remove sensitive infomation for iOS

fwVideoAppIdKey=FireworkVideoAppID
placehold='<string><\/string>'
infoPath="${iOSProjPath}/Runner/Info.plist"

lineIndexOfFwVideoAppIdKey=$(cat "${infoPath}" | grep -n "${fwVideoAppIdKey}" | awk -F ":" '{print $1}')

if [[ $lineIndexOfFwVideoAppIdKey = "" ]]
then
	echo "error:not found fwVideoAppIdKey!"
	exit 1
else
	# # fwVideoAppId would be at next row of fwVideoAppIdKey
	lineIndexOfFwVideoAppId=`expr $lineIndexOfFwVideoAppIdKey + 1`

	# # replace wVideoAppIdKey value with placehold
	sed -i "" "${lineIndexOfFwVideoAppId},${lineIndexOfFwVideoAppId}s/<string>.*<\/string>/${placehold}/" $infoPath  
fi

fwEnvironmentKey=FireworkEnvironment
lineIndexOfFwEnvironmentKey=$(cat "${infoPath}" | grep -n "${fwEnvironmentKey}" | awk -F ":" '{print $1}')

if [[ -z "$lineIndexOfFwEnvironmentKey" ]]
then
  echo "error:not found fwEnvironmentKey!"
  exit 1
else
  # fwEnvironment would be at next row of fwEnvironmentKey
  lineIndexOfFwEnvironment=`expr $lineIndexOfFwEnvironmentKey + 1`

  # delete fwEnvironmentKey and fwEnvironment
  sed -i "" "${lineIndexOfFwEnvironmentKey},${lineIndexOfFwEnvironment}d" $infoPath  
fi

# # # Part 2: remove sensitive infomation from info-debug.plist

infoDebugPath="${iOSProjPath}/Runner/Info-Debug.plist"

lineIndexOfFwVideoAppIdKeyFromInfoDebug=$(cat "${infoDebugPath}" | grep -n "${fwVideoAppIdKey}" | awk -F ":" '{print $1}')

if [[ $lineIndexOfFwVideoAppIdKeyFromInfoDebug = "" ]]
then
  echo "error:not found FwVideoAppIdKey From InfoDebug!"
  exit 1
else
  # # fwVideoAppId would be at next row of fwVideoAppIdKey
  lineIndexOfFwVideoAppIdFromInfoDebug=`expr $lineIndexOfFwVideoAppIdKeyFromInfoDebug + 1`

  # # replace wVideoAppIdKey value with placehold
  sed -i "" "${lineIndexOfFwVideoAppIdFromInfoDebug},${lineIndexOfFwVideoAppIdFromInfoDebug}s/<string>.*<\/string>/${placehold}/" $infoDebugPath  
fi

lineIndexOfFwEnvironmentKeyFromInfoDebug=$(cat "${infoDebugPath}" | grep -n "${fwEnvironmentKey}" | awk -F ":" '{print $1}')

if [[ -z "$lineIndexOfFwEnvironmentKeyFromInfoDebug" ]]
then
  echo "error:not found fwEnvironmentKey!"
  exit 1
else
  # fwEnvironment would be at next row of fwEnvironmentKey
  lineIndexOfFwEnvironmentFromInfoDebug=`expr $lineIndexOfFwEnvironmentKeyFromInfoDebug + 1`

  # delete fwEnvironmentKey and fwEnvironment
  sed -i "" "${lineIndexOfFwEnvironmentKeyFromInfoDebug},${lineIndexOfFwEnvironmentFromInfoDebug}d" $infoDebugPath  
fi

fwAppIdConfiguration=FIREWORK_APP_ID
fwEnvironmentConfiguration=FIREWORK_ENVIRONMENT
buildConfigurationsDirectory="${iOSProjPath}/Flutter"
for file in `ls ${buildConfigurationsDirectory}`
do
  fileExtension="${file##*.}"
  echo "file: $file fileExtension: $fileExtension"
  if [ "$fileExtension" != "xcconfig" ] || [ "$file" = "Generated.xcconfig" ]
  then
  continue;
  fi

  buildConfigurationFilePath="${buildConfigurationsDirectory}/${file}"
  firstLineOfSensitiveInfomation=$(cat "${buildConfigurationFilePath}" | grep -n FIREWORK_APP_ID | awk -F ":" '{print $1}')
  lastLineOfSensitiveInfomation=$(cat "${buildConfigurationFilePath}" | grep -n FIREWORK_ENVIRONMENT | awk -F ":" '{print $1}')
  if [[ -z "$firstLineOfSensitiveInfomation" ]]
  then
  echo "error:not found FIREWORK_APP_ID! buildConfigurationFilePath:$buildConfigurationFilePath"
  exit 1
  fi

  if [[ -z "$lastLineOfSensitiveInfomation" ]]
  then
  echo "error:not found FIREWORK_ENVIRONMENT! buildConfigurationFilePath:$buildConfigurationFilePath"
  exit 1
  fi
  # remove sensitive infomation in build configuraiton file
  sed -i "" "${firstLineOfSensitiveInfomation},${lastLineOfSensitiveInfomation}d" $buildConfigurationFilePath
  echo "remove sensitive infomation in ${buildConfigurationFilePath}"
done

echo "remove sensitive infomation for iOS finish!"
